aboutsummaryrefslogtreecommitdiff
path: root/engines/draci/sound.cpp
diff options
context:
space:
mode:
authorRobert Špalek2010-06-30 08:27:09 +0000
committerRobert Špalek2010-06-30 08:27:09 +0000
commitc7f6a5b286bad600c987922396b7328079890342 (patch)
tree89b712f809c381646dbfc0f20ccb8ab07f1ef156 /engines/draci/sound.cpp
parent764aa1a125e913fb6d9800f97136adcd13fff9ae (diff)
downloadscummvm-rg350-c7f6a5b286bad600c987922396b7328079890342.tar.gz
scummvm-rg350-c7f6a5b286bad600c987922396b7328079890342.tar.bz2
scummvm-rg350-c7f6a5b286bad600c987922396b7328079890342.zip
Generalize the sound archive framework to be able to open new formats
svn-id: r50519
Diffstat (limited to 'engines/draci/sound.cpp')
-rw-r--r--engines/draci/sound.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/engines/draci/sound.cpp b/engines/draci/sound.cpp
index 4fb2fd6309..65e7e41ac4 100644
--- a/engines/draci/sound.cpp
+++ b/engines/draci/sound.cpp
@@ -39,7 +39,7 @@
namespace Draci {
-void SoundArchive::openArchive(const Common::String &path) {
+void LegacySoundArchive::openArchive(const Common::String &path) {
// Close previously opened archive (if any)
closeArchive();
@@ -103,12 +103,12 @@ void SoundArchive::openArchive(const Common::String &path) {
}
/**
* @brief SoundArchive close method
*
* Closes the currently opened archive. It can be called explicitly to
* free up memory.
*/
-void SoundArchive::closeArchive() {
+void LegacySoundArchive::closeArchive() {
clearCache();
delete _f;
_f = NULL;
@@ -123,7 +123,7 @@ void SoundArchive::closeArchive() {
* Clears the cache of the open files inside the archive without closing it.
* If the files are subsequently accessed, they are read from the disk.
*/
-void SoundArchive::clearCache() {
+void LegacySoundArchive::clearCache() {
// Delete all cached data
for (uint i = 0; i < _sampleCount; ++i) {
_samples[i].close();
@@ -137,7 +137,7 @@ void SoundArchive::clearCache() {
*
* Loads individual samples from an archive to memory on demand.
*/
-SoundSample *SoundArchive::getSample(int i, uint freq) {
+SoundSample *LegacySoundArchive::getSample(int i, uint freq) {
// Check whether requested file exists
if (i < 0 || i >= (int) _sampleCount) {
return NULL;
@@ -103,12 +103,12 @@ void SoundArchive::openArchive(const Common::String &path) {
}
/**
- * @brief SoundArchive close method
+ * @brief LegacySoundArchive close method
*
* Closes the currently opened archive. It can be called explicitly to